==> cooktimer_0.0.4-12.tar.gz: cooktimer-0.0.4/src/opt/cooktimer/translations/cooktimer_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="nl">
<context>
    <name>ConfigWindow</name>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="598"/>
        <source>Keep backlight on</source>
        <translation type="unfinished">Beeld niet dimmen</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="600"/>
        <source>Wakeup screen on alarm</source>
        <translation type="unfinished">Scherm aan bij alarm</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="601"/>
        <source>Vibrate on alarm</source>
        <translation type="unfinished">Tril bij alarm</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="602"/>
        <source>Sound on alarm</source>
        <translation type="unfinished">Geluid bij alarm</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="603"/>
        <source>Alarm banner</source>
        <translation type="unfinished">Alarm tekst</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="624"/>
        <source>Done</source>
        <translation type="unfinished">Opslaan</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="636"/>
        <source>Alarm volume: </source>
        <translation type="unfinished">Alarm volume:</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="650"/>
        <source>Alarm volume: max</source>
        <translation type="unfinished">Alarm volume: max</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="639"/>
        <source>Alarm muted</source>
        <translation type="unfinished">Stil alarm</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="680"/>
        <source>Configuration is successfully saved</source>
        <translation type="unfinished">Configuratie is succesvol opgeslagen</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="685"/>
        <source>Could NOT save Configuration!</source>
        <translation type="unfinished">Configuratie kon niet worden opgeslagen!</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="584"/>
        <source>Configuration cooktimer</source>
        <translation type="unfinished">Configuratie cooktimer</translation>
    </message>
</context>
<context>
    <name>DishPickDialog</name>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="3181"/>
        <source>[Choose dish]</source>
        <translation type="unfinished">[Kies gerecht]</translation>
    </message>
</context>
<context>
    <name>FormWidget</name>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2609"/>
        <source>timer 2 ready!</source>
        <translation type="unfinished">timer 2 klaar!</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2721"/>
        <source>Start</source>
        <translation type="unfinished">Start</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2081"/>
        <source>Choose dish</source>
        <translation type="unfinished">Kies gerecht</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2506"/>
        <source>timer 1 ready!</source>
        <translation type="unfinished">timer 1 klaar!</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2710"/>
        <source>timer 3 ready!</source>
        <translation type="unfinished">timer 3 klaar!</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2416"/>
        <source>Stop</source>
        <translation type="unfinished">Stop</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="1780"/>
        <source>Stopwatch mode ON</source>
        <translation type="unfinished">Stopwatch mode AAN</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="1806"/>
        <source>Stopwatch mode OFF</source>
        <translation type="unfinished">Stopwatch mode UIT</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="1574"/>
        <source>Continue mode ON</source>
        <translation type="unfinished">Vervolg mode AAN</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="1579"/>
        <source>Continue mode OFF</source>
        <translation type="unfinished">Vervolg mode UIT</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="532"/>
        <source>Help</source>
        <translation type="unfinished">Help</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="549"/>
        <source>Cooktimer</source>
        <translation type="unfinished">Cooktimer</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="552"/>
        <source>Apart from the obvious functions and settings, there are some not so easily spotted:</source>
        <translation type="unfinished">Naast de vanzelfsprekende functies en instellingen, zijn er een aantal niet zo makkelijk te herkennen:</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="554"/>
        <source>Pressing a running timer bar will pause the alarm</source>
        <translation type="unfinished">Het aanraken van de tijdsbalk zal de klok pauzeren</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="555"/>
        <source>Pressing a paused timer bar will unpause the alarm</source>
        <translation type="unfinished">Het aanraken van de gepauzeerde tijdsbalk zal de klok hervatten</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="556"/>
        <source>Pressing a timer bar after showing &quot;00:00:00&quot; will silence it&apos;s alarm</source>
        <translation type="unfinished">Door op de tijdsbalk te drukken waarbij het alarm afgaat, zal het alarmsignaal stoppen</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="559"/>
        <source>Long-pressing a timer bar will (de)activate continue mode</source>
        <translation type="unfinished">Het lang indrukken van de tijdsbalk zal de &quot;vervolg-mode&quot; (de)activeren</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="560"/>
        <source>By pushing the add icon in the &quot;edit dishes&quot; menu you can set interim messages and make it preload at startup</source>
        <translation type="unfinished">Via het plus icoon in &quot;Bewerk gerechten&quot; kan men tussentijdse berichten zetten en automatisch met het gerecht opstarten</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="550"/>
        <source>Cooktimer provides three timers for preparing the perfect meal.</source>
        <translation type="unfinished">Cooktimer biedt drie timers om een perfecte maaltijd te bereiden.</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="557"/>
        <source>Long-pressing a dishpicker will reset all dish settings</source>
        <translation type="unfinished">Het lang indrukken van de gerechtknop zal alle gerechtinstellingen resetten</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="558"/>
        <source>Long-pressing a timepicker will switch between countdown and stopwatch</source>
        <translation type="unfinished">Het lang indrukken van de tijdkiesknop zal wisselen tussen aftellen en stopwatch</translation>
    </message>
</context>
<context>
    <name>MyMainWindow</name>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="373"/>
        <source>&amp;About</source>
        <translation type="unfinished">&amp;Over</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="336"/>
        <source>&amp;Landscape</source>
        <translation type="unfinished">&amp;Landschap</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="338"/>
        <source>&amp;Portrait</source>
        <translation type="unfinished">&amp;Portret</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="340"/>
        <source>&amp;Autorotate</source>
        <translation type="unfinished">&amp;Autorotatie</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="346"/>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Instellingen</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="370"/>
        <source>&amp;Edit dishes</source>
        <translation type="unfinished">&amp;Bewerk gerechten</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="371"/>
        <source>&amp;Custom alarm sound</source>
        <translation type="unfinished">&amp;Alarm geluid</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="521"/>
        <source>About</source>
        <translation type="unfinished">Over</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="524"/>
        <source>Created by</source>
        <translation type="unfinished">Gemaakt door</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="482"/>
        <source>Configuration is successfully saved</source>
        <translation type="unfinished">Configuratie is succesvol opgeslagen</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="487"/>
        <source>Could NOT save Configuration!</source>
        <translation type="unfinished">Configuratie kon niet worden opgeslagen!</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="372"/>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Help</translation>
    </message>
</context>
<context>
    <name>TimePickDialog</name>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="3034"/>
        <source>Done</source>
        <translation type="unfinished">Opslaan</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="3033"/>
        <source>| hours | minutes | seconds |</source>
        <translation type="unfinished">| uren | minuten | seconden |</translation>
    </message>
</context>
<context>
    <name>extItemWindow</name>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="3281"/>
        <source>Message</source>
        <translation type="unfinished">Bericht</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="3287"/>
        <source>time</source>
        <translation type="unfinished">tijd</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="3325"/>
        <source>Done</source>
        <translation type="unfinished">Opslaan</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="3272"/>
        <source>set on start</source>
        <translation type="unfinished">bij opstarten</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="3320"/>
        <source>Alarm</source>
        <translation type="unfinished">Alarm</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="3427"/>
        <source>Message time larger then alarm time!</source>
        <translation type="unfinished">Bericht na alarmtijd!</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="3488"/>
        <source>Max of 3 presets already used!</source>
        <translation type="unfinished">Max van 3 presets al gebruikt!</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="3504"/>
        <source>Messages are successfully saved</source>
        <translation type="unfinished">Berichten succesvol opgeslagen</translation>
    </message>
</context>
<context>
    <name>fileWindow</name>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="982"/>
        <source>Choose soundfile</source>
        <translation type="unfinished">Kies geluidsfragment</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="1109"/>
        <source>Configuration is successfully saved</source>
        <translation type="unfinished">Configuratie is succesvol opgeslagen</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="1114"/>
        <source>Could NOT save Configuration!</source>
        <translation type="unfinished">Configuratie kon niet worden opgeslagen!</translation>
    </message>
</context>
<context>
    <name>itemWindow</name>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="769"/>
        <source>Dish cooktimes</source>
        <translation type="unfinished">Gerecht kooktijden</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="797"/>
        <source>Done</source>
        <translation type="unfinished">Opslaan</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="798"/>
        <source>New</source>
        <translation type="unfinished">Nieuw</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="946"/>
        <source>time</source>
        <translation type="unfinished">tijd</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="937"/>
        <source>Configuration is successfully saved</source>
        <translation type="unfinished">Configuratie is succesvol opgeslagen</translation>
    </message>
</context>
</TS>

==> cooktimer_0.0.4-14.tar.gz: cooktimer-0.0.4/src/opt/cooktimer/translations/cooktimer_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>ConfigWindow</name>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="601"/>
        <source>Keep backlight on</source>
        <translation type="unfinished">Beeld niet dimmen</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="603"/>
        <source>Wakeup screen on alarm</source>
        <translation type="unfinished">Scherm aan bij alarm</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="604"/>
        <source>Vibrate on alarm</source>
        <translation type="unfinished">Tril bij alarm</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="605"/>
        <source>Sound on alarm</source>
        <translation type="unfinished">Geluid bij alarm</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="606"/>
        <source>Alarm banner</source>
        <translation type="unfinished">Alarm tekst</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="627"/>
        <source>Done</source>
        <translation type="unfinished">Opslaan</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="639"/>
        <source>Alarm volume: </source>
        <translation type="unfinished">Alarm volume:</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="653"/>
        <source>Alarm volume: max</source>
        <translation type="unfinished">Alarm volume: max</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="642"/>
        <source>Alarm muted</source>
        <translation type="unfinished">Stil alarm</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="683"/>
        <source>Configuration is successfully saved</source>
        <translation type="unfinished">Configuratie is succesvol opgeslagen</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="688"/>
        <source>Could NOT save Configuration!</source>
        <translation type="unfinished">Configuratie kon niet worden opgeslagen!</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="587"/>
        <source>Configuration cooktimer</source>
        <translation type="unfinished">Configuratie cooktimer</translation>
    </message>
</context>
<context>
    <name>DishPickDialog</name>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2611"/>
        <source>[Choose dish]</source>
        <translation type="unfinished">[Kies gerecht]</translation>
    </message>
</context>
<context>
    <name>FormWidget</name>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2152"/>
        <source>timer 2 ready!</source>
        <translation type="unfinished">timer 2 klaar!</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2239"/>
        <source>Start</source>
        <translation type="unfinished">Start</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="1824"/>
        <source>Choose dish</source>
        <translation type="unfinished">Kies gerecht</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2073"/>
        <source>timer 1 ready!</source>
        <translation type="unfinished">timer 1 klaar!</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2230"/>
        <source>timer 3 ready!</source>
        <translation type="unfinished">timer 3 klaar!</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2004"/>
        <source>Stop</source>
        <translation type="unfinished">Stop</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="1515"/>
        <source>Stopwatch mode ON</source>
        <translation type="unfinished">Stopwatch mode AAN</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="1534"/>
        <source>Stopwatch mode OFF</source>
        <translation type="unfinished">Stopwatch mode UIT</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="1639"/>
        <source>Continue mode ON</source>
        <translation type="unfinished">Vervolg mode AAN</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="1644"/>
        <source>Continue mode OFF</source>
        <translation type="unfinished">Vervolg mode UIT</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="535"/>
        <source>Help</source>
        <translation type="unfinished">Help</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="552"/>
        <source>Cooktimer</source>
        <translation type="unfinished">Cooktimer</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="555"/>
        <source>Apart from the obvious functions and settings, there are some not so easily spotted:</source>
        <translation type="unfinished">Naast de vanzelfsprekende functies en instellingen, zijn er een aantal niet zo makkelijk te herkennen:</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="557"/>
        <source>Pressing a running timer bar will pause the alarm</source>
        <translation type="unfinished">Het aanraken van de tijdsbalk zal de klok pauzeren</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="558"/>
        <source>Pressing a paused timer bar will unpause the alarm</source>
        <translation type="unfinished">Het aanraken van de gepauzeerde tijdsbalk zal de klok hervatten</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="559"/>
        <source>Pressing a timer bar after showing &quot;00:00:00&quot; will silence it&apos;s alarm</source>
        <translation type="unfinished">Door op de tijdsbalk te drukken waarbij het alarm afgaat, zal het alarmsignaal stoppen</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="563"/>
        <source>By pushing the add icon in the &quot;edit dishes&quot; menu you can set interim messages and make it preload at startup</source>
        <translation type="unfinished">Via het plus icoon in &quot;Bewerk gerechten&quot; kan men tussentijdse berichten zetten en automatisch met het gerecht opstarten</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="553"/>
        <source>Cooktimer provides three timers for preparing the perfect meal.</source>
        <translation type="unfinished">Cooktimer biedt drie timers om een perfecte maaltijd te bereiden.</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="560"/>
        <source>Long-pressing a dishpicker will reset all dish settings</source>
        <translation type="unfinished">Het lang indrukken van de gerechtknop zal alle gerechtinstellingen resetten</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="561"/>
        <source>Long-pressing a timepicker will toggle continue mode</source>
        <translation type="unfinished">Het lang indrukken van de tijd keuzetoets zal de vervolgmode aan of uit zetten</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="562"/>
        <source>Long-pressing a timer bar will toggle stopwatch mode</source>
        <translation type="unfinished">Het lang indrukken van de tijdsbalk zal de stopwatchmode aan of uit zetten</translation>
    </message>
</context>
<context>
    <name>MyMainWindow</name>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="376"/>
        <source>&amp;About</source>
        <translation type="unfinished">&amp;Over</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="339"/>
        <source>&amp;Landscape</source>
        <translation type="unfinished">&amp;Landschap</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="341"/>
        <source>&amp;Portrait</source>
        <translation type="unfinished">&amp;Portret</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="343"/>
        <source>&amp;Autorotate</source>
        <translation type="unfinished">&amp;Autorotatie</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="349"/>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Instellingen</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="373"/>
        <source>&amp;Edit dishes</source>
        <translation type="unfinished">&amp;Bewerk gerechten</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="374"/>
        <source>&amp;Custom alarm sound</source>
        <translation type="unfinished">&amp;Alarm geluid</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="524"/>
        <source>About</source>
        <translation type="unfinished">Over</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="527"/>
        <source>Created by</source>
        <translation type="unfinished">Gemaakt door</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="485"/>
        <source>Configuration is successfully saved</source>
        <translation type="unfinished">Configuratie is succesvol opgeslagen</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="490"/>
        <source>Could NOT save Configuration!</source>
        <translation type="unfinished">Configuratie kon niet worden opgeslagen!</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="375"/>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Help</translation>
    </message>
</context>
<context>
    <name>TimePickDialog</name>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2464"/>
        <source>Done</source>
        <translation type="unfinished">Opslaan</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2463"/>
        <source>| hours | minutes | seconds |</source>
        <translation type="unfinished">| uren | minuten | seconden |</translation>
    </message>
</context>
<context>
    <name>extItemWindow</name>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2711"/>
        <source>Message</source>
        <translation type="unfinished">Bericht</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2717"/>
        <source>time</source>
        <translation type="unfinished">tijd</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2755"/>
        <source>Done</source>
        <translation type="unfinished">Opslaan</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2702"/>
        <source>set on start</source>
        <translation type="unfinished">bij opstarten</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2750"/>
        <source>Alarm</source>
        <translation type="unfinished">Alarm</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2857"/>
        <source>Message time larger then alarm time!</source>
        <translation type="unfinished">Bericht na alarmtijd!</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2918"/>
        <source>Max of 3 presets already used!</source>
        <translation type="unfinished">Max van 3 presets al gebruikt!</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="2934"/>
        <source>Messages are successfully saved</source>
        <translation type="unfinished">Berichten succesvol opgeslagen</translation>
    </message>
</context>
<context>
    <name>fileWindow</name>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="985"/>
        <source>Choose soundfile</source>
        <translation type="unfinished">Kies geluidsfragment</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="1112"/>
        <source>Configuration is successfully saved</source>
        <translation type="unfinished">Configuratie is succesvol opgeslagen</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="1117"/>
        <source>Could NOT save Configuration!</source>
        <translation type="unfinished">Configuratie kon niet worden opgeslagen!</translation>
    </message>
</context>
<context>
    <name>itemWindow</name>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="772"/>
        <source>Dish cooktimes</source>
        <translation type="unfinished">Gerecht kooktijden</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="800"/>
        <source>Done</source>
        <translation type="unfinished">Opslaan</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="801"/>
        <source>New</source>
        <translation type="unfinished">Nieuw</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="949"/>
        <source>time</source>
        <translation type="unfinished">tijd</translation>
    </message>
    <message>
        <location filename="src/opt/cooktimer/cooktimer" line="940"/>
        <source>Configuration is successfully saved</source>
        <translation type="unfinished">Configuratie is succesvol opgeslagen</translation>
    </message>
</context>
</TS>
